@@ -1,6 +1,7 @@
 use std::borrow::Borrow;
 use std::borrow::BorrowMut;
 use std::fmt::Debug;
+use std::rc::Rc;
 
 use crate::*;
 
@@ -60,3 +61,47 @@ impl<P : Parse> Parse for Vec<P> {
 	}
 
 }
+
+impl<P : Parse> Parse for Box<P> {
+
+	fn parse(position: &mut Position) -> Result<Self> {
+
+		Ok(Box::new(P::parse(position)?))
+
+	}
+
+}
+
+impl<P : Parse> Parse for Rc<P> {
+
+	fn parse(position: &mut Position) -> Result<Self> {
+
+		Ok(Rc::new(P::parse(position)?))
+
+	}
+
+}
+
+impl Parse for bool {
+
+	fn parse(position: &mut Position) -> Result<Self> {
+		
+		let result = Pattern::<"(true|false)">::parse(position);
+
+		match result {
+
+			Ok(pattern) => {
+
+				let boolean = pattern.matched_string().parse::<bool>().unwrap();
+
+				Ok(boolean)
+
+			},
+
+			Err(error) => Err(error)
+
+		}
+
+	}
+
+}
\ No newline at end of file
